@@ -54,4 +54,4 @@ class PatchLoggerAdapter(logging.LoggerAdapter):
 
 #: logger for monkey patchs. use like this:
 #: patch_logger.info(<func>`patched_func`)
-patch_logger = PatchLoggerAdapter(_patch_logger, None)
+patch_logger = PatchLoggerAdapter(_patch_logger, {})
