@@ -138,8 +138,8 @@ class AuditEntry(db.Model):
             except (UnicodeDecodeError, TypeError):
                 try:
                     changes = pickle.loads(self.changes_pickle, encoding="bytes")
-                except BaseException as e:
-                    logger.warning("migration error on audit entry:", e)
+                except BaseException:
+                    logger.warning("migration error on audit entry:", exc_info=True)
                     changes = Changes()
 
             if isinstance(changes, dict):
