@@ -5,4 +5,4 @@ from __future__ import absolute_import, division, print_function
 from .models import register
 from .service import SettingsService
 
-__all__ = ['SettingsService', 'register']
+__all__ = ["SettingsService", "register"]
