@@ -25,17 +25,15 @@ from abilian.core.util import local_dt
 from abilian.i18n import _
 from abilian.services.audit import AuditEntry
 from abilian.services.security import SecurityAudit
+from abilian.web.admin import AdminPanel
 from abilian.web.util import url_for
 from abilian.web.views.base import JSONView
 
-from ..panel import AdminPanel
-
 
 def format_date_for_input(date):
     date_fmt = get_locale().date_formats["short"].pattern
-    date_fmt = date_fmt.replace("MMMM", "MM").replace(
-        "MMM", "MM"
-    )  # force numerical months
+    # force numerical months
+    date_fmt = date_fmt.replace("MMMM", "MM").replace("MMM", "MM")
     return format_date(date, date_fmt)
 
 
@@ -303,15 +301,13 @@ class AuditEntryPresenter(BaseEntryPresenter):
         assert isinstance(entry, AuditEntry)
         super(AuditEntryPresenter, self).__init__(entry.user, entry.happened_at)
         self.entry = entry
-
-    # def __lt__(self, other):
-    #     return self.entry < other.entry
+        self.entity_deleted = entry.entity is None
 
     def render(self):
+        # type: () -> Text
         render = render_template_string
         e = self.entry
         user = render(self._USER_FMT, user=e.user)
-        self.entity_deleted = e.entity is None
         entity_html = e.entity_name
 
         if not self.entity_deleted:
@@ -357,6 +353,7 @@ class SecurityEntryPresenter(BaseEntryPresenter):
         self.entry = entry
 
     def render(self):
+        # type: () -> Text
         render = render_template_string
         e = self.entry
 
