@@ -29,13 +29,13 @@ class UsersPanel(AdminPanel):
             "sDom": "lfFritip",
             "aaSorting": [[1, "asc"]],
             "aoColumns": [
-                dict(bSortable=False),
-                dict(asSorting=["asc", "desc"]),
-                dict(asSorting=["asc", "desc"]),
-                dict(bSortable=False),
-                dict(bSortable=False),
-                dict(bSortable=False),
-                dict(asSorting=["asc", "desc"]),
+                {"bSortable": False},
+                {"asSorting": ["asc", "desc"]},
+                {"asSorting": ["asc", "desc"]},
+                {"bSortable": False},
+                {"bSortable": False},
+                {"bSortable": False},
+                {"asSorting": ["asc", "desc"]},
             ],
             "bFilter": True,
             "oLanguage": {
