@@ -16,13 +16,10 @@ from abilian.web.forms.validators import required
 class AttachmentForm(Form):
 
     blob = FileField(
-        _l('file'),
-        validators=[required()],
-        filters=[strip],
-        multiple=False,
+        _l("file"), validators=[required()], filters=[strip], multiple=False
     )
 
-    description = StringField(_l('description (optional)'), filters=[strip])
+    description = StringField(_l("description (optional)"), filters=[strip])
 
     class Meta:
         model = Attachment
