@@ -10,6 +10,7 @@ import babel.dates
 import PIL.Image
 from flask import current_app, flash, g, redirect, render_template, request, \
     url_for
+from six import PY2
 from werkzeug.exceptions import InternalServerError
 from wtforms.fields import StringField
 from wtforms.validators import ValidationError
@@ -104,10 +105,11 @@ class UserPreferencesPanel(PreferencePanel):
         photo = g.user.photo
         if photo:
             # subclass str/bytes to set additional 'url' attribute
+
             photo = type(
-                b"Photo",
+                b"Photo" if PY2 else "Photo",
                 (bytes,),
-                dict(object=photo, url=url_for("users.photo", user_id=g.user.id)),
+                {"object": photo, "url": url_for("users.photo", user_id=g.user.id)},
             )
             data["photo"] = photo
 
