@@ -9,6 +9,7 @@ from flask_wtf.file import FileField, file_required
 from werkzeug.exceptions import BadRequest, NotFound
 from werkzeug.utils import secure_filename
 
+from abilian.core.util import unwrap
 from abilian.web import csrf, url_for
 from abilian.web.blueprints import Blueprint
 from abilian.web.forms import Form
@@ -26,7 +27,7 @@ class BaseUploadsView(object):
     def prepare_args(self, args, kwargs):
         args, kwargs = super(BaseUploadsView, self).prepare_args(args, kwargs)
         self.uploads = current_app.extensions["uploads"]
-        self.user = current_user._get_current_object()
+        self.user = unwrap(current_user)
         return args, kwargs
 
 
