@@ -139,11 +139,12 @@ class ObjectView(BaseObjectView):
         :attr:`form` is initialized here. See also :meth:`View.prepare_args`.
         """
         args, kwargs = super(ObjectView, self).prepare_args(args, kwargs)
-        self.form = self.Form(**self.get_form_kwargs())
+        form_kwargs = self.get_form_kwargs()
+        self.form = self.Form(**form_kwargs)
         return args, kwargs
 
     def get_form_kwargs(self):
-        kw = dict(obj=self.obj)
+        kw = {"obj": self.obj}
         if issubclass(self.Form, forms.Form) and self.permission:
             kw["permission"] = self.permission
         return kw
@@ -271,7 +272,7 @@ class ObjectEdit(ObjectView):
     def handle_action(self, action):
         for button in self._buttons:
             if action == button.name:
-                if not button.available(dict(view=self)):
+                if not button.available({"view": self}):
                     raise ValueError(
                         'Action "{}" not available' "".format(action.encode("utf-8"))
                     )
@@ -581,7 +582,7 @@ class JSONBaseSearch(JSONView):
         for obj in self.get_results(q, **kwargs):
             results.append(self.get_item(obj))
 
-        return dict(results=results)
+        return {"results": results}
 
     def get_results(self, q, *args, **kwargs):
         raise NotImplementedError
@@ -631,7 +632,7 @@ class JSONModelSearch(JSONBaseSearch):
         :param obj: Instance object
         :returns: a dictionnary with at least `id` and `text` values
         """
-        return dict(id=obj.id, text=self.get_label(obj), name=obj.name)
+        return {"id": obj.id, "text": self.get_label(obj), "name": obj.name}
 
 
 class JSONWhooshSearch(JSONBaseSearch):
@@ -672,4 +673,4 @@ class JSONWhooshSearch(JSONBaseSearch):
         :param hit: Hit object from Whoosh
         :returns: a dictionnary with at least `id` and `text` values
         """
-        return dict(id=hit["id"], text=hit["name"], name=hit["name"])
+        return {"id": hit["id"], "text": hit["name"], "name": hit["name"]}
